@@ -251,35 +251,43 @@ repo_info = \
         },
         "get_config_maps":{
             "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["config_map", True, None, None, True, True]
+            "ret":["config_map", True, None, None, True, True],
+            "key": "{cluster_name}:{namespace_name}:config_maps"
         },
         "get_deployments":{
             "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["deployment", True, None, None, True, True]
+            "ret":["deployment", True, None, None, True, True],
+            "key": "{cluster_name}:{namespace_name}:deployments"
         },
         "get_existing_nodes":{
             "args":[["cluster_name", False, "Name"]],
-            "ret":["node_info", True, None, None, True, True]
+            "ret":["node_info", True, None, None, True, True],
+            "key": "{cluster_name}:existing_nodes"
         },
         "get_existing_nodes_by_name":{
             "args":[["node_name", False, "Name"]],
-            "ret":["node_info", True, None, None, True, True]
+            "ret":["node_info", True, None, None, True, True],
+            "key": "{node_name}:existing_nodes"
         },
         "get_namespaces":{
             "args":[["cluster_name", False, "Name"]],
-            "ret":["namespace", True, None, None, True, True]
+            "ret":["namespace", True, None, None, True, True],
+            "key": "{cluster_name}:namespaces"
         },
         "get_node_metas":{
             "args":[["cluster_name", False, "Name"]],
-            "ret":["node_meta", True, None, None, True, True]
+            "ret":["node_meta", True, None, None, True, True],
+            "key": "{cluster_name}:node_metas"
         },
         "get_pods":{
             "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["pod", True, None, None, True, True]
+            "ret":["pod", True, None, None, True, True],
+            "key": "{cluster_name}:{namespace_name}:pods"
         },
         "get_secrets":{
             "args":[["cluster_name", False, "Name"], ["namespace_name", False, "Name"]],
-            "ret":["secret", True, None, None, True, True]
+            "ret":["secret", True, None, None, True, True],
+            "key": "{cluster_name}:{namespace_name}:secrets"
         },
         "upload_to_oss_from_pod":{
             "args":[["pod_oss_operation_info", True, "PodOSSOperationInfo"]]
